@@ -10,7 +10,7 @@
 #ifndef PDFIO_PRIVATE_H
 #  define PDFIO_PRIVATE_H
 #  ifdef _WIN32
-#    define _CRT_SECURE_NO_WARNINGS	// Disable bogus VS warnings/errors...
+#    define _CRT_SECURE_NO_WARNINGS 1	// Disable bogus VS warnings/errors...
 #  endif // _WIN32
 #  include "pdfio.h"
 #  include <stdarg.h>
@@ -28,16 +28,16 @@
 #    define access	_access		// Map standard POSIX/C99 names
 #    define close	_close
 #    define fileno	_fileno
-#    define lseek	_lseek
+#    define lseek(f,o,w) (off_t)_lseek((f),(long)(o),(w))
 #    define mkdir(d,p)	_mkdir(d)
 #    define open	_open
-#    define read	_read
+#    define read(f,b,s)	_read((f),(b),(unsigned)(s))
 #    define rmdir	_rmdir
 #    define snprintf	_snprintf
 #    define strdup	_strdup
 #    define unlink	_unlink
 #    define vsnprintf	_vsnprintf
-#    define write	_write
+#    define write(f,b,s) _write((f),(b),(unsigned)(s))
 #    ifndef F_OK
 #      define F_OK	00		// POSIX parameters/flags
 #      define W_OK	02
@@ -221,7 +221,7 @@ struct _pdfio_dict_s			// Dictionary
 typedef struct _pdfio_objmap_s		// PDF object map
 {
   pdfio_obj_t	*obj;			// Object for this file
-  pdfio_file_t	*src_pdf;		// Source PDF file
+  unsigned char	src_id[32];		// Source PDF file file identifier
   size_t	src_number;		// Source object number
 } _pdfio_objmap_t;
 
@@ -236,6 +236,7 @@ typedef struct _pdfio_strbuf_s		// PDF string buffer
 struct _pdfio_file_s			// PDF file structure
 {
   char		*filename;		// Filename
+  unsigned char	file_id[32];		// File identifier bytes
   struct lconv	*loc;			// Locale data
   char		*version;		// Version number
   pdfio_rect_t	media_box,		// Default MediaBox value
@@ -270,6 +271,7 @@ struct _pdfio_file_s			// PDF file structure
   pdfio_obj_t	*cp1252_obj,		// CP1252 font encoding object
 		*unicode_obj;		// Unicode font encoding object
   pdfio_array_t	*id_array;		// ID array
+  bool		encrypt_metadata;	// Encrypt metadata?
 
   // Allocated data elements
   size_t	num_arrays,		// Number of arrays
@@ -339,6 +341,7 @@ struct _pdfio_stream_s			// Stream
 
 extern size_t		_pdfio_strlcpy(char *dst, const char *src, size_t dstsize) _PDFIO_INTERNAL;
 extern double		_pdfio_strtod(pdfio_file_t *pdf, const char *s) _PDFIO_INTERNAL;
+extern void		_pdfio_utf16cpy(char *dst, const unsigned char *src, size_t srclen, size_t dstsize) _PDFIO_INTERNAL;
 extern ssize_t		_pdfio_vsnprintf(pdfio_file_t *pdf, char *buffer, size_t bufsize, const char *format, va_list ap) _PDFIO_INTERNAL;
 
 extern bool		_pdfioArrayDecrypt(pdfio_file_t *pdf, pdfio_obj_t *obj, pdfio_array_t *a, size_t depth) _PDFIO_INTERNAL;
@@ -382,7 +385,7 @@ extern bool		_pdfioFileError(pdfio_file_t *pdf, const char *format, ...) _PDFIO_
 extern pdfio_obj_t	*_pdfioFileFindMappedObj(pdfio_file_t *pdf, pdfio_file_t *src_pdf, size_t src_number) _PDFIO_INTERNAL;
 extern bool		_pdfioFileFlush(pdfio_file_t *pdf) _PDFIO_INTERNAL;
 extern int		_pdfioFileGetChar(pdfio_file_t *pdf) _PDFIO_INTERNAL;
-extern bool		_pdfioFileGets(pdfio_file_t *pdf, char *buffer, size_t bufsize) _PDFIO_INTERNAL;
+extern bool		_pdfioFileGets(pdfio_file_t *pdf, char *buffer, size_t bufsize, bool discard) _PDFIO_INTERNAL;
 extern ssize_t		_pdfioFilePeek(pdfio_file_t *pdf, void *buffer, size_t bytes) _PDFIO_INTERNAL;
 extern bool		_pdfioFilePrintf(pdfio_file_t *pdf, const char *format, ...) _PDFIO_INTERNAL;
 extern bool		_pdfioFilePuts(pdfio_file_t *pdf, const char *s) _PDFIO_INTERNAL;
